@@ -1,26 +1,19 @@
 package SDL::Mixer;
 use strict;
 use warnings;
-use vars qw($VERSION $XS_VERSION @ISA @EXPORT @EXPORT_OK);
+use vars qw(@ISA @EXPORT @EXPORT_OK);
 require Exporter;
 require DynaLoader;
 use SDL::Constants qw(:SDL::Mixer :SDL::Audio);
 our @ISA = qw(Exporter DynaLoader);
 
-our $VERSION    = '2.541_10';
-our $XS_VERSION = $VERSION;
-$VERSION = eval $VERSION;
-
 use SDL::Internal::Loader;
 internal_load_dlls(__PACKAGE__);
 
 bootstrap SDL::Mixer;
 
 use base 'Exporter';
-our @EXPORT = (
-	@{ $SDL::Constants::EXPORT_TAGS{'SDL::Mixer'} },
-	@{ $SDL::Constants::EXPORT_TAGS{'SDL::Audio'} }
-);
+our @EXPORT      = (@{ $SDL::Constants::EXPORT_TAGS{'SDL::Mixer'} }, @{ $SDL::Constants::EXPORT_TAGS{'SDL::Audio'} });
 our %EXPORT_TAGS = (
 	all      => \@EXPORT,
 	init     => $SDL::Constants::EXPORT_TAGS{'SDL::Mixer/init'},
